package com.weenergies.cs.ebpp.action;

import java.util.ArrayList;
import java.util.List;

import javax.faces.model.SelectItem;

import org.jboss.seam.ScopeType;
import org.jboss.seam.annotations.Factory;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.Out;
import org.jboss.seam.annotations.Scope;
import org.jboss.seam.annotations.datamodel.DataModel;
import org.jboss.seam.annotations.datamodel.DataModelSelection;
import org.jboss.seam.international.StatusMessages;
import org.jboss.seam.log.Log;

import com.weenergies.cs.interactive_bill.utils.CsServiceInjector;
import com.weenergies.cs.model.Account;
import com.weenergies.cs.model.Address;
import com.weenergies.cs.model.Bill;
import com.weenergies.cs.model.BillSummary;
import com.weenergies.cs.model.Customer;
import com.weenergies.cs.services.generated.cis_bill_service_account.BillingService;
import com.weenergies.cs.services.generated.cis_service_myaccount.BillData;
import com.weenergies.cs.services.generated.cis_service_myaccount.CommonInput;
import com.weenergies.cs.services.generated.cis_service_myaccount.GetAccountListInput;
import com.weenergies.cs.services.generated.cis_service_myaccount.GetAccountListOutput;
import com.weenergies.cs.services.generated.cis_service_myaccount.GetBillListInput;
import com.weenergies.cs.services.generated.cis_service_myaccount.MyAccountData;
import com.weenergies.cs.services.generated.cis_service_myaccount.MyAccountService;

@Name("bHomeView")
@Scope(ScopeType.SESSION)
public class BHomeView {
	@Logger
	private Log log;
	
	@In
	StatusMessages statusMessages;
	
	@In(required = false)
	@Out(required = false)
	String accountNumber;
	
	@In(value = CsServiceInjector.MY_ACCOUNT_SERVICE, required = true)
	MyAccountService myAccountSrv;
	@In(value = CsServiceInjector.BILLING_SERVICE, required = true)
	BillingService billSrv;
	
	public List<String> accounts;
	
	@Out(required = false)
	public List<javax.faces.model.SelectItem> selAccounts;
	
	@In(required = false)
	public String customerId;
	
	@In(required = false)
	public String energyAccountId;
	
	@DataModel
	private List<BillSummary> billSummaries;
	
	@DataModelSelection
	private BillSummary billSummary;
	
	public void bHomeView() {
		// implement your business logic here
		log.info("bHomeView.bHomeView() action called");
		statusMessages.add("bHomeView");
	}
	
	@Factory("billSummaries")
	public void getBillList() throws Exception {
		accounts = new ArrayList<String>();
		selAccounts = new ArrayList<javax.faces.model.SelectItem>();
		CommonInput commonInput = new CommonInput();
		GetAccountListInput dataInput = new GetAccountListInput();
		GetAccountListOutput output;
		// GetAccountListOutput accountListOut;
		
		commonInput.setLoginId("soapuiId");
		dataInput.setProfileId(customerId);
		// dataInput.setProfileId(customerId);
		log.debug("Custome rID == " + customerId);
		log.debug("call the WS in bill home....");
		// Call the Bill Service SOAP WS
		output = myAccountSrv.getAccountList(commonInput, dataInput);
		GetBillListInput billInput = new GetBillListInput();
		billInput.setProfileId(customerId);
		try {
			List<MyAccountData> accountList = output.getData().getMyAccounts();
			List<BillData> billList =
					myAccountSrv.getBillList(commonInput, billInput).getData().getBills();
			billSummaries = new ArrayList<BillSummary>();
			for (MyAccountData myData : accountList) {
				BillData currentBillData = null;
				boolean found = false;
				for (BillData bill : billList) {
					if (bill.getEnergyAccountId().equals(myData.getEnergyAccountId()) && !found) {
						currentBillData = bill;
						found = true;
					}
				}
				
				Bill currentBill = new Bill(currentBillData);
				BillSummary summary = new BillSummary();
				summary.setAccount(new Account());
				summary.getAccount().setEnergyAccountId(myData.getEnergyAccountId());
				summary.getAccount().setNickname(myData.getNickname());
				summary.setCurrentBill(currentBill);
				summary.getAccount().setPaperFreeBillingFlag(
						currentBillData.isPaperFreeBillingFlag());
				summary.getAccount().setReminderEmailFlag(currentBillData.isDueDateReminderFlag());
				summary.getAccount().setCustomer(new Customer());
				summary.getAccount().getCustomer()
						.setCustomerName(myData.getCustomer().getCustomerName());
				summary.getAccount().getCustomer()
						.setPrimaryCustomerFlag(myData.getCustomer().isPrimaryCustomerFlag());
				summary.getAccount().setAddress(new Address(myData.getPremiseAddress()));
				
				accounts.add(myData.getEnergyAccountId());
				selAccounts.add(new SelectItem(myData.getEnergyAccountId(),
						processAccountNumber(myData.getEnergyAccountId()) + ' '
								+ summary.getAccount().getNickname()));
				accountNumber = (String)selAccounts.get(0).getValue();
				log.debug("Account Number == " + accountNumber);
				billSummaries.add(summary);
			}
			if (billSummaries.size() > 0) {
				billSummary = billSummaries.get(0);
			}
		} catch (Exception e) {
			log.debug(e);
		}
		log.debug("finshed get bill list in BHomeView");
	}
	
	public List<BillSummary> getBillSummaries() {
		return billSummaries;
	}
	
	public BillSummary getBillSummary() {
		return billSummary;
	}
	
	public String getCustomerId() {
		return customerId;
	}
	
	public String getEnergyAccountId() {
		return energyAccountId;
	}
	
	public void setBillSummaries(List<BillSummary> billSummaries) {
		this.billSummaries = billSummaries;
	}
	
	public void setBillSummary(BillSummary billSummary) {
		this.billSummary = billSummary;
	}
	
	public void setCustomerId(String customerId) {
		this.customerId = customerId;
	}
	
	public void setEnergyAccountId(String energyAccountID) {
		energyAccountId = energyAccountID;
	}
	
	// Fill in the empty spaces with 0's and mask with some dashes
	private String processAccountNumber(String acctNumber) {
		// String acctNumber = acctNumber.toString();
		log.debug(acctNumber);
		int initialLength = acctNumber.length();
		if (acctNumber.length() < 10) {
			for (int x = 0; x < (10 - initialLength); x++) {
				acctNumber = '0' + acctNumber;
				log.debug(acctNumber);
			}
		}
		log.debug("acctNumber == " + acctNumber);
		String begin = acctNumber.substring(0, 4);
		String middle = acctNumber.substring(4, 7);
		String end = acctNumber.substring(7, 10);
		
		return begin + '-' + middle + '-' + end;
		
	}
	
}
